# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from grafeas.grafeas_v1.types import attestation as g_attestation
from grafeas.grafeas_v1.types import build as g_build
from grafeas.grafeas_v1.types import common
from grafeas.grafeas_v1.types import compliance as g_compliance
from grafeas.grafeas_v1.types import deployment as g_deployment
from grafeas.grafeas_v1.types import discovery as g_discovery
from grafeas.grafeas_v1.types import dsse_attestation as g_dsse_attestation
from grafeas.grafeas_v1.types import image as g_image
from grafeas.grafeas_v1.types import package as g_package
from grafeas.grafeas_v1.types import sbom
from grafeas.grafeas_v1.types import secret as g_secret
from grafeas.grafeas_v1.types import upgrade as g_upgrade
from grafeas.grafeas_v1.types import vex
from grafeas.grafeas_v1.types import vulnerability as g_vulnerability

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "Occurrence",
        "Note",
        "GetOccurrenceRequest",
        "ListOccurrencesRequest",
        "ListOccurrencesResponse",
        "DeleteOccurrenceRequest",
        "CreateOccurrenceRequest",
        "UpdateOccurrenceRequest",
        "GetNoteRequest",
        "GetOccurrenceNoteRequest",
        "ListNotesRequest",
        "ListNotesResponse",
        "DeleteNoteRequest",
        "CreateNoteRequest",
        "UpdateNoteRequest",
        "ListNoteOccurrencesRequest",
        "ListNoteOccurrencesResponse",
        "BatchCreateNotesRequest",
        "BatchCreateNotesResponse",
        "BatchCreateOccurrencesRequest",
        "BatchCreateOccurrencesResponse",
    },
)


class Occurrence(proto.Message):
    r"""An instance of an analysis type that has been found on a
    resource.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Output only. The name of the occurrence in the form of
            ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
        resource_uri (str):
            Required. Immutable. A URI that represents the resource for
            which the occurrence applies. For example,
            ``https://gcr.io/project/image@sha256:123abc`` for a Docker
            image.
        note_name (str):
            Required. Immutable. The analysis note associated with this
            occurrence, in the form of
            ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``. This field can
            be used as a filter in list requests.
        kind (grafeas.grafeas_v1.types.NoteKind):
            Output only. This explicitly denotes which of
            the occurrence details are specified. This field
            can be used as a filter in list requests.
        remediation (str):
            A description of actions that can be taken to
            remedy the note.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time this occurrence was
            created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time this occurrence was
            last updated.
        vulnerability (grafeas.grafeas_v1.types.VulnerabilityOccurrence):
            Describes a security vulnerability.

            This field is a member of `oneof`_ ``details``.
        build (grafeas.grafeas_v1.types.BuildOccurrence):
            Describes a verifiable build.

            This field is a member of `oneof`_ ``details``.
        image (grafeas.grafeas_v1.types.ImageOccurrence):
            Describes how this resource derives from the
            basis in the associated note.

            This field is a member of `oneof`_ ``details``.
        package (grafeas.grafeas_v1.types.PackageOccurrence):
            Describes the installation of a package on
            the linked resource.

            This field is a member of `oneof`_ ``details``.
        deployment (grafeas.grafeas_v1.types.DeploymentOccurrence):
            Describes the deployment of an artifact on a
            runtime.

            This field is a member of `oneof`_ ``details``.
        discovery (grafeas.grafeas_v1.types.DiscoveryOccurrence):
            Describes when a resource was discovered.

            This field is a member of `oneof`_ ``details``.
        attestation (grafeas.grafeas_v1.types.AttestationOccurrence):
            Describes an attestation of an artifact.

            This field is a member of `oneof`_ ``details``.
        upgrade (grafeas.grafeas_v1.types.UpgradeOccurrence):
            Describes an available package upgrade on the
            linked resource.

            This field is a member of `oneof`_ ``details``.
        compliance (grafeas.grafeas_v1.types.ComplianceOccurrence):
            Describes a compliance violation on a linked
            resource.

            This field is a member of `oneof`_ ``details``.
        dsse_attestation (grafeas.grafeas_v1.types.DSSEAttestationOccurrence):
            Describes an attestation of an artifact using
            dsse.

            This field is a member of `oneof`_ ``details``.
        sbom_reference (grafeas.grafeas_v1.types.SBOMReferenceOccurrence):
            Describes a specific SBOM reference
            occurrences.

            This field is a member of `oneof`_ ``details``.
        secret (grafeas.grafeas_v1.types.SecretOccurrence):
            Describes a secret.

            This field is a member of `oneof`_ ``details``.
        envelope (grafeas.grafeas_v1.types.Envelope):
            https://github.com/secure-systems-lab/dsse
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    resource_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )
    note_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    kind: common.NoteKind = proto.Field(
        proto.ENUM,
        number=4,
        enum=common.NoteKind,
    )
    remediation: str = proto.Field(
        proto.STRING,
        number=5,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    vulnerability: g_vulnerability.VulnerabilityOccurrence = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="details",
        message=g_vulnerability.VulnerabilityOccurrence,
    )
    build: g_build.BuildOccurrence = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="details",
        message=g_build.BuildOccurrence,
    )
    image: g_image.ImageOccurrence = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="details",
        message=g_image.ImageOccurrence,
    )
    package: g_package.PackageOccurrence = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof="details",
        message=g_package.PackageOccurrence,
    )
    deployment: g_deployment.DeploymentOccurrence = proto.Field(
        proto.MESSAGE,
        number=12,
        oneof="details",
        message=g_deployment.DeploymentOccurrence,
    )
    discovery: g_discovery.DiscoveryOccurrence = proto.Field(
        proto.MESSAGE,
        number=13,
        oneof="details",
        message=g_discovery.DiscoveryOccurrence,
    )
    attestation: g_attestation.AttestationOccurrence = proto.Field(
        proto.MESSAGE,
        number=14,
        oneof="details",
        message=g_attestation.AttestationOccurrence,
    )
    upgrade: g_upgrade.UpgradeOccurrence = proto.Field(
        proto.MESSAGE,
        number=15,
        oneof="details",
        message=g_upgrade.UpgradeOccurrence,
    )
    compliance: g_compliance.ComplianceOccurrence = proto.Field(
        proto.MESSAGE,
        number=16,
        oneof="details",
        message=g_compliance.ComplianceOccurrence,
    )
    dsse_attestation: g_dsse_attestation.DSSEAttestationOccurrence = proto.Field(
        proto.MESSAGE,
        number=17,
        oneof="details",
        message=g_dsse_attestation.DSSEAttestationOccurrence,
    )
    sbom_reference: sbom.SBOMReferenceOccurrence = proto.Field(
        proto.MESSAGE,
        number=19,
        oneof="details",
        message=sbom.SBOMReferenceOccurrence,
    )
    secret: g_secret.SecretOccurrence = proto.Field(
        proto.MESSAGE,
        number=20,
        oneof="details",
        message=g_secret.SecretOccurrence,
    )
    envelope: common.Envelope = proto.Field(
        proto.MESSAGE,
        number=18,
        message=common.Envelope,
    )


class Note(proto.Message):
    r"""A type of analysis that can be done for a resource.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Output only. The name of the note in the form of
            ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
        short_description (str):
            A one sentence description of this note.
        long_description (str):
            A detailed description of this note.
        kind (grafeas.grafeas_v1.types.NoteKind):
            Output only. The type of analysis. This field
            can be used as a filter in list requests.
        related_url (MutableSequence[grafeas.grafeas_v1.types.RelatedUrl]):
            URLs associated with this note.
        expiration_time (google.protobuf.timestamp_pb2.Timestamp):
            Time of expiration for this note. Empty if
            note does not expire.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time this note was created.
            This field can be used as a filter in list
            requests.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time this note was last
            updated. This field can be used as a filter in
            list requests.
        related_note_names (MutableSequence[str]):
            Other notes related to this note.
        vulnerability (grafeas.grafeas_v1.types.VulnerabilityNote):
            A note describing a package vulnerability.

            This field is a member of `oneof`_ ``type``.
        build (grafeas.grafeas_v1.types.BuildNote):
            A note describing build provenance for a
            verifiable build.

            This field is a member of `oneof`_ ``type``.
        image (grafeas.grafeas_v1.types.ImageNote):
            A note describing a base image.

            This field is a member of `oneof`_ ``type``.
        package (grafeas.grafeas_v1.types.PackageNote):
            A note describing a package hosted by various
            package managers.

            This field is a member of `oneof`_ ``type``.
        deployment (grafeas.grafeas_v1.types.DeploymentNote):
            A note describing something that can be
            deployed.

            This field is a member of `oneof`_ ``type``.
        discovery (grafeas.grafeas_v1.types.DiscoveryNote):
            A note describing the initial analysis of a
            resource.

            This field is a member of `oneof`_ ``type``.
        attestation (grafeas.grafeas_v1.types.AttestationNote):
            A note describing an attestation role.

            This field is a member of `oneof`_ ``type``.
        upgrade (grafeas.grafeas_v1.types.UpgradeNote):
            A note describing available package upgrades.

            This field is a member of `oneof`_ ``type``.
        compliance (grafeas.grafeas_v1.types.ComplianceNote):
            A note describing a compliance check.

            This field is a member of `oneof`_ ``type``.
        dsse_attestation (grafeas.grafeas_v1.types.DSSEAttestationNote):
            A note describing a dsse attestation note.

            This field is a member of `oneof`_ ``type``.
        vulnerability_assessment (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote):
            A note describing a vulnerability assessment.

            This field is a member of `oneof`_ ``type``.
        sbom_reference (grafeas.grafeas_v1.types.SBOMReferenceNote):
            A note describing an SBOM reference.

            This field is a member of `oneof`_ ``type``.
        secret (grafeas.grafeas_v1.types.SecretNote):
            A note describing a secret.

            This field is a member of `oneof`_ ``type``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    short_description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    long_description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    kind: common.NoteKind = proto.Field(
        proto.ENUM,
        number=4,
        enum=common.NoteKind,
    )
    related_url: MutableSequence[common.RelatedUrl] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=common.RelatedUrl,
    )
    expiration_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        message=timestamp_pb2.Timestamp,
    )
    related_note_names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=9,
    )
    vulnerability: g_vulnerability.VulnerabilityNote = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="type",
        message=g_vulnerability.VulnerabilityNote,
    )
    build: g_build.BuildNote = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof="type",
        message=g_build.BuildNote,
    )
    image: g_image.ImageNote = proto.Field(
        proto.MESSAGE,
        number=12,
        oneof="type",
        message=g_image.ImageNote,
    )
    package: g_package.PackageNote = proto.Field(
        proto.MESSAGE,
        number=13,
        oneof="type",
        message=g_package.PackageNote,
    )
    deployment: g_deployment.DeploymentNote = proto.Field(
        proto.MESSAGE,
        number=14,
        oneof="type",
        message=g_deployment.DeploymentNote,
    )
    discovery: g_discovery.DiscoveryNote = proto.Field(
        proto.MESSAGE,
        number=15,
        oneof="type",
        message=g_discovery.DiscoveryNote,
    )
    attestation: g_attestation.AttestationNote = proto.Field(
        proto.MESSAGE,
        number=16,
        oneof="type",
        message=g_attestation.AttestationNote,
    )
    upgrade: g_upgrade.UpgradeNote = proto.Field(
        proto.MESSAGE,
        number=17,
        oneof="type",
        message=g_upgrade.UpgradeNote,
    )
    compliance: g_compliance.ComplianceNote = proto.Field(
        proto.MESSAGE,
        number=18,
        oneof="type",
        message=g_compliance.ComplianceNote,
    )
    dsse_attestation: g_dsse_attestation.DSSEAttestationNote = proto.Field(
        proto.MESSAGE,
        number=19,
        oneof="type",
        message=g_dsse_attestation.DSSEAttestationNote,
    )
    vulnerability_assessment: vex.VulnerabilityAssessmentNote = proto.Field(
        proto.MESSAGE,
        number=20,
        oneof="type",
        message=vex.VulnerabilityAssessmentNote,
    )
    sbom_reference: sbom.SBOMReferenceNote = proto.Field(
        proto.MESSAGE,
        number=21,
        oneof="type",
        message=sbom.SBOMReferenceNote,
    )
    secret: g_secret.SecretNote = proto.Field(
        proto.MESSAGE,
        number=22,
        oneof="type",
        message=g_secret.SecretNote,
    )


class GetOccurrenceRequest(proto.Message):
    r"""Request to get an occurrence.

    Attributes:
        name (str):
            The name of the occurrence in the form of
            ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListOccurrencesRequest(proto.Message):
    r"""Request to list occurrences.

    Attributes:
        parent (str):
            The name of the project to list occurrences for in the form
            of ``projects/[PROJECT_ID]``.
        filter (str):
            The filter expression.
        page_size (int):
            Number of occurrences to return in the list.
            Must be positive. Max allowed page size is 1000.
            If not specified, page size defaults to 20.
        page_token (str):
            Token to provide to skip to a particular spot
            in the list.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListOccurrencesResponse(proto.Message):
    r"""Response for listing occurrences.

    Attributes:
        occurrences (MutableSequence[grafeas.grafeas_v1.types.Occurrence]):
            The occurrences requested.
        next_page_token (str):
            The next pagination token in the list response. It should be
            used as ``page_token`` for the following request. An empty
            value means no more results.
    """

    @property
    def raw_page(self):
        return self

    occurrences: MutableSequence["Occurrence"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Occurrence",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteOccurrenceRequest(proto.Message):
    r"""Request to delete an occurrence.

    Attributes:
        name (str):
            The name of the occurrence in the form of
            ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateOccurrenceRequest(proto.Message):
    r"""Request to create a new occurrence.

    Attributes:
        parent (str):
            The name of the project in the form of
            ``projects/[PROJECT_ID]``, under which the occurrence is to
            be created.
        occurrence (grafeas.grafeas_v1.types.Occurrence):
            The occurrence to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    occurrence: "Occurrence" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Occurrence",
    )


class UpdateOccurrenceRequest(proto.Message):
    r"""Request to update an occurrence.

    Attributes:
        name (str):
            The name of the occurrence in the form of
            ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
        occurrence (grafeas.grafeas_v1.types.Occurrence):
            The updated occurrence.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The fields to update.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    occurrence: "Occurrence" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Occurrence",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=3,
        message=field_mask_pb2.FieldMask,
    )


class GetNoteRequest(proto.Message):
    r"""Request to get a note.

    Attributes:
        name (str):
            The name of the note in the form of
            ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class GetOccurrenceNoteRequest(proto.Message):
    r"""Request to get the note to which the specified occurrence is
    attached.

    Attributes:
        name (str):
            The name of the occurrence in the form of
            ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListNotesRequest(proto.Message):
    r"""Request to list notes.

    Attributes:
        parent (str):
            The name of the project to list notes for in the form of
            ``projects/[PROJECT_ID]``.
        filter (str):
            The filter expression.
        page_size (int):
            Number of notes to return in the list. Must
            be positive. Max allowed page size is 1000. If
            not specified, page size defaults to 20.
        page_token (str):
            Token to provide to skip to a particular spot
            in the list.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListNotesResponse(proto.Message):
    r"""Response for listing notes.

    Attributes:
        notes (MutableSequence[grafeas.grafeas_v1.types.Note]):
            The notes requested.
        next_page_token (str):
            The next pagination token in the list response. It should be
            used as ``page_token`` for the following request. An empty
            value means no more results.
    """

    @property
    def raw_page(self):
        return self

    notes: MutableSequence["Note"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Note",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteNoteRequest(proto.Message):
    r"""Request to delete a note.

    Attributes:
        name (str):
            The name of the note in the form of
            ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateNoteRequest(proto.Message):
    r"""Request to create a new note.

    Attributes:
        parent (str):
            The name of the project in the form of
            ``projects/[PROJECT_ID]``, under which the note is to be
            created.
        note_id (str):
            The ID to use for this note.
        note (grafeas.grafeas_v1.types.Note):
            The note to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    note_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    note: "Note" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Note",
    )


class UpdateNoteRequest(proto.Message):
    r"""Request to update a note.

    Attributes:
        name (str):
            The name of the note in the form of
            ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
        note (grafeas.grafeas_v1.types.Note):
            The updated note.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The fields to update.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    note: "Note" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Note",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=3,
        message=field_mask_pb2.FieldMask,
    )


class ListNoteOccurrencesRequest(proto.Message):
    r"""Request to list occurrences for a note.

    Attributes:
        name (str):
            The name of the note to list occurrences for in the form of
            ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
        filter (str):
            The filter expression.
        page_size (int):
            Number of occurrences to return in the list.
        page_token (str):
            Token to provide to skip to a particular spot
            in the list.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListNoteOccurrencesResponse(proto.Message):
    r"""Response for listing occurrences for a note.

    Attributes:
        occurrences (MutableSequence[grafeas.grafeas_v1.types.Occurrence]):
            The occurrences attached to the specified
            note.
        next_page_token (str):
            Token to provide to skip to a particular spot
            in the list.
    """

    @property
    def raw_page(self):
        return self

    occurrences: MutableSequence["Occurrence"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Occurrence",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class BatchCreateNotesRequest(proto.Message):
    r"""Request to create notes in batch.

    Attributes:
        parent (str):
            The name of the project in the form of
            ``projects/[PROJECT_ID]``, under which the notes are to be
            created.
        notes (MutableMapping[str, grafeas.grafeas_v1.types.Note]):
            The notes to create. Max allowed length is
            1000.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    notes: MutableMapping[str, "Note"] = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=2,
        message="Note",
    )


class BatchCreateNotesResponse(proto.Message):
    r"""Response for creating notes in batch.

    Attributes:
        notes (MutableSequence[grafeas.grafeas_v1.types.Note]):
            The notes that were created.
    """

    notes: MutableSequence["Note"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Note",
    )


class BatchCreateOccurrencesRequest(proto.Message):
    r"""Request to create occurrences in batch.

    Attributes:
        parent (str):
            The name of the project in the form of
            ``projects/[PROJECT_ID]``, under which the occurrences are
            to be created.
        occurrences (MutableSequence[grafeas.grafeas_v1.types.Occurrence]):
            The occurrences to create. Max allowed length
            is 1000.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    occurrences: MutableSequence["Occurrence"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="Occurrence",
    )


class BatchCreateOccurrencesResponse(proto.Message):
    r"""Response for creating occurrences in batch.

    Attributes:
        occurrences (MutableSequence[grafeas.grafeas_v1.types.Occurrence]):
            The occurrences that were created.
    """

    occurrences: MutableSequence["Occurrence"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Occurrence",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import any_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "Recipe",
        "Completeness",
        "Metadata",
        "BuilderConfig",
        "InTotoProvenance",
    },
)


class Recipe(proto.Message):
    r"""Steps taken to build the artifact.
    For a TaskRun, typically each container corresponds to one step
    in the recipe.

    Attributes:
        type_ (str):
            URI indicating what type of recipe was
            performed. It determines the meaning of
            recipe.entryPoint, recipe.arguments,
            recipe.environment, and materials.
        defined_in_material (int):
            Index in materials containing the recipe
            steps that are not implied by recipe.type. For
            example, if the recipe type were "make", then
            this would point to the source containing the
            Makefile, not the make program itself. Set to -1
            if the recipe doesn't come from a material, as
            zero is default unset value for int64.
        entry_point (str):
            String identifying the entry point into the
            build. This is often a path to a configuration
            file and/or a target label within that file. The
            syntax and meaning are defined by recipe.type.
            For example, if the recipe type were "make",
            then this would reference the directory in which
            to run make as well as which target to use.
        arguments (MutableSequence[google.protobuf.any_pb2.Any]):
            Collection of all external inputs that
            influenced the build on top of
            recipe.definedInMaterial and recipe.entryPoint.
            For example, if the recipe type were "make",
            then this might be the flags passed to make
            aside from the target, which is captured in
            recipe.entryPoint. Since the arguments field can
            greatly vary in structure, depending on the
            builder and recipe type, this is of form "Any".
        environment (MutableSequence[google.protobuf.any_pb2.Any]):
            Any other builder-controlled inputs necessary
            for correctly evaluating the recipe. Usually
            only needed for reproducing the build but not
            evaluated as part of policy. Since the
            environment field can greatly vary in structure,
            depending on the builder and recipe type, this
            is of form "Any".
    """

    type_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    defined_in_material: int = proto.Field(
        proto.INT64,
        number=2,
    )
    entry_point: str = proto.Field(
        proto.STRING,
        number=3,
    )
    arguments: MutableSequence[any_pb2.Any] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=any_pb2.Any,
    )
    environment: MutableSequence[any_pb2.Any] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=any_pb2.Any,
    )


class Completeness(proto.Message):
    r"""Indicates that the builder claims certain fields in this
    message to be complete.

    Attributes:
        arguments (bool):
            If true, the builder claims that
            recipe.arguments is complete, meaning that all
            external inputs are properly captured in the
            recipe.
        environment (bool):
            If true, the builder claims that
            recipe.environment is claimed to be complete.
        materials (bool):
            If true, the builder claims that materials
            are complete, usually through some controls to
            prevent network access. Sometimes called
            "hermetic".
    """

    arguments: bool = proto.Field(
        proto.BOOL,
        number=1,
    )
    environment: bool = proto.Field(
        proto.BOOL,
        number=2,
    )
    materials: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class Metadata(proto.Message):
    r"""Other properties of the build.

    Attributes:
        build_invocation_id (str):
            Identifies the particular build invocation,
            which can be useful for finding associated logs
            or other ad-hoc analysis. The value SHOULD be
            globally unique, per in-toto Provenance spec.
        build_started_on (google.protobuf.timestamp_pb2.Timestamp):
            The timestamp of when the build started.
        build_finished_on (google.protobuf.timestamp_pb2.Timestamp):
            The timestamp of when the build completed.
        completeness (grafeas.grafeas_v1.types.Completeness):
            Indicates that the builder claims certain
            fields in this message to be complete.
        reproducible (bool):
            If true, the builder claims that running the
            recipe on materials will produce bit-for-bit
            identical output.
    """

    build_invocation_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    build_started_on: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    build_finished_on: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    completeness: "Completeness" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="Completeness",
    )
    reproducible: bool = proto.Field(
        proto.BOOL,
        number=5,
    )


class BuilderConfig(proto.Message):
    r"""

    Attributes:
        id (str):

    """

    id: str = proto.Field(
        proto.STRING,
        number=1,
    )


class InTotoProvenance(proto.Message):
    r"""

    Attributes:
        builder_config (grafeas.grafeas_v1.types.BuilderConfig):
            required
        recipe (grafeas.grafeas_v1.types.Recipe):
            Identifies the configuration used for the
            build. When combined with materials, this SHOULD
            fully describe the build, such that re-running
            this recipe results in bit-for-bit identical
            output (if the build is reproducible).
        metadata (grafeas.grafeas_v1.types.Metadata):

        materials (MutableSequence[str]):
            The collection of artifacts that influenced
            the build including sources, dependencies, build
            tools, base images, and so on. This is
            considered to be incomplete unless
            metadata.completeness.materials is true. Unset
            or null is equivalent to empty.
    """

    builder_config: "BuilderConfig" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="BuilderConfig",
    )
    recipe: "Recipe" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Recipe",
    )
    metadata: "Metadata" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Metadata",
    )
    materials: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "CVSSVersion",
        "CVSSv3",
        "CVSS",
    },
)


class CVSSVersion(proto.Enum):
    r"""CVSS Version.

    Values:
        CVSS_VERSION_UNSPECIFIED (0):
            No description available.
        CVSS_VERSION_2 (1):
            No description available.
        CVSS_VERSION_3 (2):
            No description available.
    """
    CVSS_VERSION_UNSPECIFIED = 0
    CVSS_VERSION_2 = 1
    CVSS_VERSION_3 = 2


class CVSSv3(proto.Message):
    r"""Common Vulnerability Scoring System version 3.
    For details, see
    https://www.first.org/cvss/specification-document

    Attributes:
        base_score (float):
            The base score is a function of the base
            metric scores.
        exploitability_score (float):

        impact_score (float):

        attack_vector (grafeas.grafeas_v1.types.CVSSv3.AttackVector):
            Base Metrics
            Represents the intrinsic characteristics of a
            vulnerability that are constant over time and
            across user environments.
        attack_complexity (grafeas.grafeas_v1.types.CVSSv3.AttackComplexity):

        privileges_required (grafeas.grafeas_v1.types.CVSSv3.PrivilegesRequired):

        user_interaction (grafeas.grafeas_v1.types.CVSSv3.UserInteraction):

        scope (grafeas.grafeas_v1.types.CVSSv3.Scope):

        confidentiality_impact (grafeas.grafeas_v1.types.CVSSv3.Impact):

        integrity_impact (grafeas.grafeas_v1.types.CVSSv3.Impact):

        availability_impact (grafeas.grafeas_v1.types.CVSSv3.Impact):

    """

    class AttackVector(proto.Enum):
        r"""

        Values:
            ATTACK_VECTOR_UNSPECIFIED (0):
                No description available.
            ATTACK_VECTOR_NETWORK (1):
                No description available.
            ATTACK_VECTOR_ADJACENT (2):
                No description available.
            ATTACK_VECTOR_LOCAL (3):
                No description available.
            ATTACK_VECTOR_PHYSICAL (4):
                No description available.
        """
        ATTACK_VECTOR_UNSPECIFIED = 0
        ATTACK_VECTOR_NETWORK = 1
        ATTACK_VECTOR_ADJACENT = 2
        ATTACK_VECTOR_LOCAL = 3
        ATTACK_VECTOR_PHYSICAL = 4

    class AttackComplexity(proto.Enum):
        r"""

        Values:
            ATTACK_COMPLEXITY_UNSPECIFIED (0):
                No description available.
            ATTACK_COMPLEXITY_LOW (1):
                No description available.
            ATTACK_COMPLEXITY_HIGH (2):
                No description available.
        """
        ATTACK_COMPLEXITY_UNSPECIFIED = 0
        ATTACK_COMPLEXITY_LOW = 1
        ATTACK_COMPLEXITY_HIGH = 2

    class PrivilegesRequired(proto.Enum):
        r"""

        Values:
            PRIVILEGES_REQUIRED_UNSPECIFIED (0):
                No description available.
            PRIVILEGES_REQUIRED_NONE (1):
                No description available.
            PRIVILEGES_REQUIRED_LOW (2):
                No description available.
            PRIVILEGES_REQUIRED_HIGH (3):
                No description available.
        """
        PRIVILEGES_REQUIRED_UNSPECIFIED = 0
        PRIVILEGES_REQUIRED_NONE = 1
        PRIVILEGES_REQUIRED_LOW = 2
        PRIVILEGES_REQUIRED_HIGH = 3

    class UserInteraction(proto.Enum):
        r"""

        Values:
            USER_INTERACTION_UNSPECIFIED (0):
                No description available.
            USER_INTERACTION_NONE (1):
                No description available.
            USER_INTERACTION_REQUIRED (2):
                No description available.
        """
        USER_INTERACTION_UNSPECIFIED = 0
        USER_INTERACTION_NONE = 1
        USER_INTERACTION_REQUIRED = 2

    class Scope(proto.Enum):
        r"""

        Values:
            SCOPE_UNSPECIFIED (0):
                No description available.
            SCOPE_UNCHANGED (1):
                No description available.
            SCOPE_CHANGED (2):
                No description available.
        """
        SCOPE_UNSPECIFIED = 0
        SCOPE_UNCHANGED = 1
        SCOPE_CHANGED = 2

    class Impact(proto.Enum):
        r"""

        Values:
            IMPACT_UNSPECIFIED (0):
                No description available.
            IMPACT_HIGH (1):
                No description available.
            IMPACT_LOW (2):
                No description available.
            IMPACT_NONE (3):
                No description available.
        """
        IMPACT_UNSPECIFIED = 0
        IMPACT_HIGH = 1
        IMPACT_LOW = 2
        IMPACT_NONE = 3

    base_score: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    exploitability_score: float = proto.Field(
        proto.FLOAT,
        number=2,
    )
    impact_score: float = proto.Field(
        proto.FLOAT,
        number=3,
    )
    attack_vector: AttackVector = proto.Field(
        proto.ENUM,
        number=5,
        enum=AttackVector,
    )
    attack_complexity: AttackComplexity = proto.Field(
        proto.ENUM,
        number=6,
        enum=AttackComplexity,
    )
    privileges_required: PrivilegesRequired = proto.Field(
        proto.ENUM,
        number=7,
        enum=PrivilegesRequired,
    )
    user_interaction: UserInteraction = proto.Field(
        proto.ENUM,
        number=8,
        enum=UserInteraction,
    )
    scope: Scope = proto.Field(
        proto.ENUM,
        number=9,
        enum=Scope,
    )
    confidentiality_impact: Impact = proto.Field(
        proto.ENUM,
        number=10,
        enum=Impact,
    )
    integrity_impact: Impact = proto.Field(
        proto.ENUM,
        number=11,
        enum=Impact,
    )
    availability_impact: Impact = proto.Field(
        proto.ENUM,
        number=12,
        enum=Impact,
    )


class CVSS(proto.Message):
    r"""Common Vulnerability Scoring System.
    For details, see
    https://www.first.org/cvss/specification-document This is a
    message we will try to use for storing various versions of CVSS
    rather than making a separate proto for storing a specific
    version.

    Attributes:
        base_score (float):
            The base score is a function of the base
            metric scores.
        exploitability_score (float):

        impact_score (float):

        attack_vector (grafeas.grafeas_v1.types.CVSS.AttackVector):
            Base Metrics
            Represents the intrinsic characteristics of a
            vulnerability that are constant over time and
            across user environments.
        attack_complexity (grafeas.grafeas_v1.types.CVSS.AttackComplexity):

        authentication (grafeas.grafeas_v1.types.CVSS.Authentication):

        privileges_required (grafeas.grafeas_v1.types.CVSS.PrivilegesRequired):

        user_interaction (grafeas.grafeas_v1.types.CVSS.UserInteraction):

        scope (grafeas.grafeas_v1.types.CVSS.Scope):

        confidentiality_impact (grafeas.grafeas_v1.types.CVSS.Impact):

        integrity_impact (grafeas.grafeas_v1.types.CVSS.Impact):

        availability_impact (grafeas.grafeas_v1.types.CVSS.Impact):

    """

    class AttackVector(proto.Enum):
        r"""

        Values:
            ATTACK_VECTOR_UNSPECIFIED (0):
                No description available.
            ATTACK_VECTOR_NETWORK (1):
                No description available.
            ATTACK_VECTOR_ADJACENT (2):
                No description available.
            ATTACK_VECTOR_LOCAL (3):
                No description available.
            ATTACK_VECTOR_PHYSICAL (4):
                No description available.
        """
        ATTACK_VECTOR_UNSPECIFIED = 0
        ATTACK_VECTOR_NETWORK = 1
        ATTACK_VECTOR_ADJACENT = 2
        ATTACK_VECTOR_LOCAL = 3
        ATTACK_VECTOR_PHYSICAL = 4

    class AttackComplexity(proto.Enum):
        r"""

        Values:
            ATTACK_COMPLEXITY_UNSPECIFIED (0):
                No description available.
            ATTACK_COMPLEXITY_LOW (1):
                No description available.
            ATTACK_COMPLEXITY_HIGH (2):
                No description available.
            ATTACK_COMPLEXITY_MEDIUM (3):
                No description available.
        """
        ATTACK_COMPLEXITY_UNSPECIFIED = 0
        ATTACK_COMPLEXITY_LOW = 1
        ATTACK_COMPLEXITY_HIGH = 2
        ATTACK_COMPLEXITY_MEDIUM = 3

    class Authentication(proto.Enum):
        r"""

        Values:
            AUTHENTICATION_UNSPECIFIED (0):
                No description available.
            AUTHENTICATION_MULTIPLE (1):
                No description available.
            AUTHENTICATION_SINGLE (2):
                No description available.
            AUTHENTICATION_NONE (3):
                No description available.
        """
        AUTHENTICATION_UNSPECIFIED = 0
        AUTHENTICATION_MULTIPLE = 1
        AUTHENTICATION_SINGLE = 2
        AUTHENTICATION_NONE = 3

    class PrivilegesRequired(proto.Enum):
        r"""

        Values:
            PRIVILEGES_REQUIRED_UNSPECIFIED (0):
                No description available.
            PRIVILEGES_REQUIRED_NONE (1):
                No description available.
            PRIVILEGES_REQUIRED_LOW (2):
                No description available.
            PRIVILEGES_REQUIRED_HIGH (3):
                No description available.
        """
        PRIVILEGES_REQUIRED_UNSPECIFIED = 0
        PRIVILEGES_REQUIRED_NONE = 1
        PRIVILEGES_REQUIRED_LOW = 2
        PRIVILEGES_REQUIRED_HIGH = 3

    class UserInteraction(proto.Enum):
        r"""

        Values:
            USER_INTERACTION_UNSPECIFIED (0):
                No description available.
            USER_INTERACTION_NONE (1):
                No description available.
            USER_INTERACTION_REQUIRED (2):
                No description available.
        """
        USER_INTERACTION_UNSPECIFIED = 0
        USER_INTERACTION_NONE = 1
        USER_INTERACTION_REQUIRED = 2

    class Scope(proto.Enum):
        r"""

        Values:
            SCOPE_UNSPECIFIED (0):
                No description available.
            SCOPE_UNCHANGED (1):
                No description available.
            SCOPE_CHANGED (2):
                No description available.
        """
        SCOPE_UNSPECIFIED = 0
        SCOPE_UNCHANGED = 1
        SCOPE_CHANGED = 2

    class Impact(proto.Enum):
        r"""

        Values:
            IMPACT_UNSPECIFIED (0):
                No description available.
            IMPACT_HIGH (1):
                No description available.
            IMPACT_LOW (2):
                No description available.
            IMPACT_NONE (3):
                No description available.
            IMPACT_PARTIAL (4):
                No description available.
            IMPACT_COMPLETE (5):
                No description available.
        """
        IMPACT_UNSPECIFIED = 0
        IMPACT_HIGH = 1
        IMPACT_LOW = 2
        IMPACT_NONE = 3
        IMPACT_PARTIAL = 4
        IMPACT_COMPLETE = 5

    base_score: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    exploitability_score: float = proto.Field(
        proto.FLOAT,
        number=2,
    )
    impact_score: float = proto.Field(
        proto.FLOAT,
        number=3,
    )
    attack_vector: AttackVector = proto.Field(
        proto.ENUM,
        number=4,
        enum=AttackVector,
    )
    attack_complexity: AttackComplexity = proto.Field(
        proto.ENUM,
        number=5,
        enum=AttackComplexity,
    )
    authentication: Authentication = proto.Field(
        proto.ENUM,
        number=6,
        enum=Authentication,
    )
    privileges_required: PrivilegesRequired = proto.Field(
        proto.ENUM,
        number=7,
        enum=PrivilegesRequired,
    )
    user_interaction: UserInteraction = proto.Field(
        proto.ENUM,
        number=8,
        enum=UserInteraction,
    )
    scope: Scope = proto.Field(
        proto.ENUM,
        number=9,
        enum=Scope,
    )
    confidentiality_impact: Impact = proto.Field(
        proto.ENUM,
        number=10,
        enum=Impact,
    )
    integrity_impact: Impact = proto.Field(
        proto.ENUM,
        number=11,
        enum=Impact,
    )
    availability_impact: Impact = proto.Field(
        proto.ENUM,
        number=12,
        enum=Impact,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "NoteKind",
        "RelatedUrl",
        "Signature",
        "Envelope",
        "EnvelopeSignature",
        "FileLocation",
        "BaseImage",
        "LayerDetails",
        "License",
        "Digest",
    },
)


class NoteKind(proto.Enum):
    r"""Kind represents the kinds of notes supported.

    Values:
        NOTE_KIND_UNSPECIFIED (0):
            Default value. This value is unused.
        VULNERABILITY (1):
            The note and occurrence represent a package
            vulnerability.
        BUILD (2):
            The note and occurrence assert build
            provenance.
        IMAGE (3):
            This represents an image basis relationship.
        PACKAGE (4):
            This represents a package installed via a
            package manager.
        DEPLOYMENT (5):
            The note and occurrence track deployment
            events.
        DISCOVERY (6):
            The note and occurrence track the initial
            discovery status of a resource.
        ATTESTATION (7):
            This represents a logical "role" that can
            attest to artifacts.
        UPGRADE (8):
            This represents an available package upgrade.
        COMPLIANCE (9):
            This represents a Compliance Note
        DSSE_ATTESTATION (10):
            This represents a DSSE attestation Note
        VULNERABILITY_ASSESSMENT (11):
            This represents a Vulnerability Assessment.
        SBOM_REFERENCE (12):
            This represents an SBOM Reference.
        SECRET (13):
            This represents a secret.
    """
    NOTE_KIND_UNSPECIFIED = 0
    VULNERABILITY = 1
    BUILD = 2
    IMAGE = 3
    PACKAGE = 4
    DEPLOYMENT = 5
    DISCOVERY = 6
    ATTESTATION = 7
    UPGRADE = 8
    COMPLIANCE = 9
    DSSE_ATTESTATION = 10
    VULNERABILITY_ASSESSMENT = 11
    SBOM_REFERENCE = 12
    SECRET = 13


class RelatedUrl(proto.Message):
    r"""Metadata for any related URL information.

    Attributes:
        url (str):
            Specific URL associated with the resource.
        label (str):
            Label to describe usage of the URL.
    """

    url: str = proto.Field(
        proto.STRING,
        number=1,
    )
    label: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Signature(proto.Message):
    r"""Verifiers (e.g. Kritis implementations) MUST verify signatures with
    respect to the trust anchors defined in policy (e.g. a Kritis
    policy). Typically this means that the verifier has been configured
    with a map from ``public_key_id`` to public key material (and any
    required parameters, e.g. signing algorithm).

    In particular, verification implementations MUST NOT treat the
    signature ``public_key_id`` as anything more than a key lookup hint.
    The ``public_key_id`` DOES NOT validate or authenticate a public
    key; it only provides a mechanism for quickly selecting a public key
    ALREADY CONFIGURED on the verifier through a trusted channel.
    Verification implementations MUST reject signatures in any of the
    following circumstances:

    -  The ``public_key_id`` is not recognized by the verifier.
    -  The public key that ``public_key_id`` refers to does not verify
       the signature with respect to the payload.

    The ``signature`` contents SHOULD NOT be "attached" (where the
    payload is included with the serialized ``signature`` bytes).
    Verifiers MUST ignore any "attached" payload and only verify
    signatures with respect to explicitly provided payload (e.g. a
    ``payload`` field on the proto message that holds this Signature, or
    the canonical serialization of the proto message that holds this
    signature).

    Attributes:
        signature (bytes):
            The content of the signature, an opaque
            bytestring. The payload that this signature
            verifies MUST be unambiguously provided with the
            Signature during verification. A wrapper message
            might provide the payload explicitly.
            Alternatively, a message might have a canonical
            serialization that can always be unambiguously
            computed to derive the payload.
        public_key_id (str):
            The identifier for the public key that verifies this
            signature.

            -  The ``public_key_id`` is required.
            -  The ``public_key_id`` SHOULD be an RFC3986 conformant
               URI.
            -  When possible, the ``public_key_id`` SHOULD be an
               immutable reference, such as a cryptographic digest.

            Examples of valid ``public_key_id``\ s:

            OpenPGP V4 public key fingerprint:

            -  "openpgp4fpr:74FAF3B861BDA0870C7B6DEF607E48D2A663AEEA"
               See
               https://www.iana.org/assignments/uri-schemes/prov/openpgp4fpr
               for more details on this scheme.

            RFC6920 digest-named SubjectPublicKeyInfo (digest of the DER
            serialization):

            -  "ni:///sha-256;cD9o9Cq6LG3jD0iKXqEi_vdjJGecm_iXkbqVoScViaU"
            -  "nih:///sha-256;703f68f42aba2c6de30f488a5ea122fef76324679c9bf89791ba95a1271589a5".
    """

    signature: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )
    public_key_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Envelope(proto.Message):
    r"""MUST match
    https://github.com/secure-systems-lab/dsse/blob/master/envelope.proto.
    An authenticated message of arbitrary type.

    Attributes:
        payload (bytes):

        payload_type (str):

        signatures (MutableSequence[grafeas.grafeas_v1.types.EnvelopeSignature]):

    """

    payload: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )
    payload_type: str = proto.Field(
        proto.STRING,
        number=2,
    )
    signatures: MutableSequence["EnvelopeSignature"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="EnvelopeSignature",
    )


class EnvelopeSignature(proto.Message):
    r"""

    Attributes:
        sig (bytes):

        keyid (str):

    """

    sig: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )
    keyid: str = proto.Field(
        proto.STRING,
        number=2,
    )


class FileLocation(proto.Message):
    r"""Indicates the location at which a package was found.

    Attributes:
        file_path (str):
            For jars that are contained inside .war
            files, this filepath can indicate the path to
            war file combined with the path to jar file.
        layer_details (grafeas.grafeas_v1.types.LayerDetails):
            Each package found in a file should have its
            own layer metadata (that is, information from
            the origin layer of the package).
    """

    file_path: str = proto.Field(
        proto.STRING,
        number=1,
    )
    layer_details: "LayerDetails" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="LayerDetails",
    )


class BaseImage(proto.Message):
    r"""BaseImage describes a base image of a container image.

    Attributes:
        name (str):
            The name of the base image.
        repository (str):
            The repository name in which the base image
            is from.
        layer_count (int):
            The number of layers that the base image is
            composed of.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    repository: str = proto.Field(
        proto.STRING,
        number=2,
    )
    layer_count: int = proto.Field(
        proto.INT32,
        number=3,
    )


class LayerDetails(proto.Message):
    r"""Details about the layer a package was found in.

    Attributes:
        index (int):
            The index of the layer in the container
            image.
        diff_id (str):
            The diff ID (typically a sha256 hash) of the
            layer in the container image.
        chain_id (str):
            The layer chain ID (sha256 hash) of the layer
            in the container image.
            https://github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
        command (str):
            The layer build command that was used to
            build the layer. This may not be found in all
            layers depending on how the container image is
            built.
        base_images (MutableSequence[grafeas.grafeas_v1.types.BaseImage]):
            The base images the layer is found within.
    """

    index: int = proto.Field(
        proto.INT32,
        number=1,
    )
    diff_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    chain_id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    command: str = proto.Field(
        proto.STRING,
        number=3,
    )
    base_images: MutableSequence["BaseImage"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="BaseImage",
    )


class License(proto.Message):
    r"""License information.

    Attributes:
        expression (str):
            Often a single license can be used to
            represent the licensing terms. Sometimes it is
            necessary to include a choice of one or more
            licenses or some combination of license
            identifiers.
            Examples: "LGPL-2.1-only OR MIT", "LGPL-2.1-only
            AND MIT", "GPL-2.0-or-later WITH
            Bison-exception-2.2".
        comments (str):
            Comments
    """

    expression: str = proto.Field(
        proto.STRING,
        number=1,
    )
    comments: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Digest(proto.Message):
    r"""Digest information.

    Attributes:
        algo (str):
            ``SHA1``, ``SHA512`` etc.
        digest_bytes (bytes):
            Value of the digest.
    """

    algo: str = proto.Field(
        proto.STRING,
        number=1,
    )
    digest_bytes: bytes = proto.Field(
        proto.BYTES,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from grafeas.grafeas_v1.types import common

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "VulnerabilityAssessmentNote",
    },
)


class VulnerabilityAssessmentNote(proto.Message):
    r"""A single VulnerabilityAssessmentNote represents
    one particular product's vulnerability assessment for one CVE.

    Attributes:
        title (str):
            The title of the note. E.g. ``Vex-Debian-11.4``
        short_description (str):
            A one sentence description of this Vex.
        long_description (str):
            A detailed description of this Vex.
        language_code (str):
            Identifies the language used by this
            document, corresponding to IETF BCP 47 / RFC
            5646.
        publisher (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Publisher):
            Publisher details of this Note.
        product (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Product):
            The product affected by this vex.
        assessment (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment):
            Represents a vulnerability assessment for the
            product.
    """

    class Publisher(proto.Message):
        r"""Publisher contains information about the publisher of
        this Note.
        (-- api-linter: core::0123::resource-annotation=disabled
        aip.dev/not-precedent: Publisher is not a separate resource. --)

        Attributes:
            name (str):
                Name of the publisher.
                Examples: 'Google', 'Google Cloud Platform'.
            issuing_authority (str):
                Provides information about the authority of
                the issuing party to release the document, in
                particular, the party's constituency and
                responsibilities or other obligations.
            publisher_namespace (str):
                The context or namespace.
                Contains a URL which is under control of the
                issuing party and can be used as a globally
                unique identifier for that issuing party.
                Example: https://csaf.io
        """

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        issuing_authority: str = proto.Field(
            proto.STRING,
            number=2,
        )
        publisher_namespace: str = proto.Field(
            proto.STRING,
            number=3,
        )

    class Product(proto.Message):
        r"""Product contains information about a product and how to
        uniquely identify it.
        (-- api-linter: core::0123::resource-annotation=disabled
        aip.dev/not-precedent: Product is not a separate resource. --)


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            name (str):
                Name of the product.
            id (str):
                Token that identifies a product so that it
                can be referred to from other parts in the
                document. There is no predefined format as long
                as it uniquely identifies a group in the context
                of the current document.
            generic_uri (str):
                Contains a URI which is vendor-specific.
                Example: The artifact repository URL of an
                image.

                This field is a member of `oneof`_ ``identifier``.
        """

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        id: str = proto.Field(
            proto.STRING,
            number=2,
        )
        generic_uri: str = proto.Field(
            proto.STRING,
            number=3,
            oneof="identifier",
        )

    class Assessment(proto.Message):
        r"""Assessment provides all information that is related to a
        single vulnerability for this product.

        Attributes:
            cve (str):
                Holds the MITRE standard Common Vulnerabilities and
                Exposures (CVE) tracking number for the vulnerability.
                Deprecated: Use vulnerability_id instead to denote CVEs.
            vulnerability_id (str):
                The vulnerability identifier for this
                Assessment. Will hold one of common identifiers
                e.g. CVE, GHSA etc.
            short_description (str):
                A one sentence description of this Vex.
            long_description (str):
                A detailed description of this Vex.
            related_uris (MutableSequence[grafeas.grafeas_v1.types.RelatedUrl]):
                Holds a list of references associated with
                this vulnerability item and assessment. These
                uris have additional information about the
                vulnerability and the assessment itself. E.g.
                Link to a document which details how this
                assessment concluded the state of this
                vulnerability.
            state (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.State):
                Provides the state of this Vulnerability
                assessment.
            impacts (MutableSequence[str]):
                Contains information about the impact of this
                vulnerability, this will change with time.
            justification (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.Justification):
                Justification provides the justification when the state of
                the assessment if NOT_AFFECTED.
            remediations (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.Remediation]):
                Specifies details on how to handle (and
                presumably, fix) a vulnerability.
        """

        class State(proto.Enum):
            r"""Provides the state of this Vulnerability assessment.

            Values:
                STATE_UNSPECIFIED (0):
                    No state is specified.
                AFFECTED (1):
                    This product is known to be affected by this
                    vulnerability.
                NOT_AFFECTED (2):
                    This product is known to be not affected by
                    this vulnerability.
                FIXED (3):
                    This product contains a fix for this
                    vulnerability.
                UNDER_INVESTIGATION (4):
                    It is not known yet whether these versions
                    are or are not affected by the vulnerability.
                    However, it is still under investigation.
            """
            STATE_UNSPECIFIED = 0
            AFFECTED = 1
            NOT_AFFECTED = 2
            FIXED = 3
            UNDER_INVESTIGATION = 4

        class Justification(proto.Message):
            r"""Justification provides the justification when the state of the
            assessment if NOT_AFFECTED.

            Attributes:
                justification_type (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.Justification.JustificationType):
                    The justification type for this
                    vulnerability.
                details (str):
                    Additional details on why this justification
                    was chosen.
            """

            class JustificationType(proto.Enum):
                r"""Provides the type of justification.

                Values:
                    JUSTIFICATION_TYPE_UNSPECIFIED (0):
                        JUSTIFICATION_TYPE_UNSPECIFIED.
                    COMPONENT_NOT_PRESENT (1):
                        The vulnerable component is not present in
                        the product.
                    VULNERABLE_CODE_NOT_PRESENT (2):
                        The vulnerable code is not present. Typically
                        this case occurs when source code is configured
                        or built in a way that excludes the vulnerable
                        code.
                    VULNERABLE_CODE_NOT_IN_EXECUTE_PATH (3):
                        The vulnerable code can not be executed.
                        Typically this case occurs when the product
                        includes the vulnerable code but does not call
                        or use the vulnerable code.
                    VULNERABLE_CODE_CANNOT_BE_CONTROLLED_BY_ADVERSARY (4):
                        The vulnerable code cannot be controlled by
                        an attacker to exploit the vulnerability.
                    INLINE_MITIGATIONS_ALREADY_EXIST (5):
                        The product includes built-in protections or
                        features that prevent exploitation of the
                        vulnerability. These built-in protections cannot
                        be subverted by the attacker and cannot be
                        configured or disabled by the user. These
                        mitigations completely prevent exploitation
                        based on known attack vectors.
                """
                JUSTIFICATION_TYPE_UNSPECIFIED = 0
                COMPONENT_NOT_PRESENT = 1
                VULNERABLE_CODE_NOT_PRESENT = 2
                VULNERABLE_CODE_NOT_IN_EXECUTE_PATH = 3
                VULNERABLE_CODE_CANNOT_BE_CONTROLLED_BY_ADVERSARY = 4
                INLINE_MITIGATIONS_ALREADY_EXIST = 5

            justification_type: "VulnerabilityAssessmentNote.Assessment.Justification.JustificationType" = proto.Field(
                proto.ENUM,
                number=1,
                enum="VulnerabilityAssessmentNote.Assessment.Justification.JustificationType",
            )
            details: str = proto.Field(
                proto.STRING,
                number=2,
            )

        class Remediation(proto.Message):
            r"""Specifies details on how to handle (and presumably, fix) a
            vulnerability.

            Attributes:
                remediation_type (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.Remediation.RemediationType):
                    The type of remediation that can be applied.
                details (str):
                    Contains a comprehensive human-readable
                    discussion of the remediation.
                remediation_uri (grafeas.grafeas_v1.types.RelatedUrl):
                    Contains the URL where to obtain the
                    remediation.
            """

            class RemediationType(proto.Enum):
                r"""The type of remediation that can be applied.

                Values:
                    REMEDIATION_TYPE_UNSPECIFIED (0):
                        No remediation type specified.
                    MITIGATION (1):
                        A MITIGATION is available.
                    NO_FIX_PLANNED (2):
                        No fix is planned.
                    NONE_AVAILABLE (3):
                        Not available.
                    VENDOR_FIX (4):
                        A vendor fix is available.
                    WORKAROUND (5):
                        A workaround is available.
                """
                REMEDIATION_TYPE_UNSPECIFIED = 0
                MITIGATION = 1
                NO_FIX_PLANNED = 2
                NONE_AVAILABLE = 3
                VENDOR_FIX = 4
                WORKAROUND = 5

            remediation_type: "VulnerabilityAssessmentNote.Assessment.Remediation.RemediationType" = proto.Field(
                proto.ENUM,
                number=1,
                enum="VulnerabilityAssessmentNote.Assessment.Remediation.RemediationType",
            )
            details: str = proto.Field(
                proto.STRING,
                number=2,
            )
            remediation_uri: common.RelatedUrl = proto.Field(
                proto.MESSAGE,
                number=3,
                message=common.RelatedUrl,
            )

        cve: str = proto.Field(
            proto.STRING,
            number=1,
        )
        vulnerability_id: str = proto.Field(
            proto.STRING,
            number=9,
        )
        short_description: str = proto.Field(
            proto.STRING,
            number=2,
        )
        long_description: str = proto.Field(
            proto.STRING,
            number=3,
        )
        related_uris: MutableSequence[common.RelatedUrl] = proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message=common.RelatedUrl,
        )
        state: "VulnerabilityAssessmentNote.Assessment.State" = proto.Field(
            proto.ENUM,
            number=5,
            enum="VulnerabilityAssessmentNote.Assessment.State",
        )
        impacts: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=6,
        )
        justification: "VulnerabilityAssessmentNote.Assessment.Justification" = (
            proto.Field(
                proto.MESSAGE,
                number=7,
                message="VulnerabilityAssessmentNote.Assessment.Justification",
            )
        )
        remediations: MutableSequence[
            "VulnerabilityAssessmentNote.Assessment.Remediation"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=8,
            message="VulnerabilityAssessmentNote.Assessment.Remediation",
        )

    title: str = proto.Field(
        proto.STRING,
        number=1,
    )
    short_description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    long_description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=4,
    )
    publisher: Publisher = proto.Field(
        proto.MESSAGE,
        number=5,
        message=Publisher,
    )
    product: Product = proto.Field(
        proto.MESSAGE,
        number=6,
        message=Product,
    )
    assessment: Assessment = proto.Field(
        proto.MESSAGE,
        number=7,
        message=Assessment,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "Layer",
        "Fingerprint",
        "ImageNote",
        "ImageOccurrence",
    },
)


class Layer(proto.Message):
    r"""Layer holds metadata specific to a layer of a Docker image.

    Attributes:
        directive (str):
            Required. The recovered Dockerfile directive
            used to construct this layer. See
            https://docs.docker.com/engine/reference/builder/
            for more information.
        arguments (str):
            The recovered arguments to the Dockerfile
            directive.
    """

    directive: str = proto.Field(
        proto.STRING,
        number=1,
    )
    arguments: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Fingerprint(proto.Message):
    r"""A set of properties that uniquely identify a given Docker
    image.

    Attributes:
        v1_name (str):
            Required. The layer ID of the final layer in
            the Docker image's v1 representation.
        v2_blob (MutableSequence[str]):
            Required. The ordered list of v2 blobs that
            represent a given image.
        v2_name (str):
            Output only. The name of the image's v2 blobs computed via:
            [bottom] := v2_blob[bottom] [N] := sha256(v2_blob[N] + " " +
            v2_name[N+1]) Only the name of the final blob is kept.
    """

    v1_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    v2_blob: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    v2_name: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ImageNote(proto.Message):
    r"""Basis describes the base image portion (Note) of the DockerImage
    relationship. Linked occurrences are derived from this or an
    equivalent image via: FROM <Basis.resource_url> Or an equivalent
    reference, e.g., a tag of the resource_url.

    Attributes:
        resource_url (str):
            Required. Immutable. The resource_url for the resource
            representing the basis of associated occurrence images.
        fingerprint (grafeas.grafeas_v1.types.Fingerprint):
            Required. Immutable. The fingerprint of the
            base image.
    """

    resource_url: str = proto.Field(
        proto.STRING,
        number=1,
    )
    fingerprint: "Fingerprint" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Fingerprint",
    )


class ImageOccurrence(proto.Message):
    r"""Details of the derived image portion of the DockerImage
    relationship. This image would be produced from a Dockerfile
    with FROM <DockerImage.Basis in attached Note>.

    Attributes:
        fingerprint (grafeas.grafeas_v1.types.Fingerprint):
            Required. The fingerprint of the derived
            image.
        distance (int):
            Output only. The number of layers by which
            this image differs from the associated image
            basis.
        layer_info (MutableSequence[grafeas.grafeas_v1.types.Layer]):
            This contains layer-specific metadata, if populated it has
            length "distance" and is ordered with [distance] being the
            layer immediately following the base image and [1] being the
            final layer.
        base_resource_url (str):
            Output only. This contains the base image URL
            for the derived image occurrence.
    """

    fingerprint: "Fingerprint" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Fingerprint",
    )
    distance: int = proto.Field(
        proto.INT32,
        number=2,
    )
    layer_info: MutableSequence["Layer"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="Layer",
    )
    base_resource_url: str = proto.Field(
        proto.STRING,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
